<?php

namespace Drupal\Tests\block_inactive_users\Unit;

use Drupal\Tests\UnitTestCase;
use Drupal\Core\DependencyInjection\ContainerBuilder;
use Drupal\block_inactive_users\InactiveUsersHandler;

/**
 * Simple test to ensure that asserts pass.
 *
 * @group block_inactive_users
 */
class InactiveUsersHandlerTest extends UnitTestCase {
  const FORM_SETTINGS_CONFIG_OBJ_NAME = "block_inactive_users.settings";
  const LOGGER_CHANNEL = "block_inactive_users";

  /**
   * A config factory service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactoryService;

  /**
   * A logger instance.
   *
   * @var \Drupal\Core\Logger\LoggerChannelFactoryInterface
   */
  protected $logger;

  /**
   * An language manager instance.
   *
   * @var \Drupal\Core\Language\LanguageManagerInterface
   */
  protected $languageManager;

  /**
   * A time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $timeService;

  /**
   * Before a test method is run, setUp() is invoked.
   */
  public function setUp() {

    parent::setUp();

    $container = new ContainerBuilder();

    $this->configFactoryService = $this->getConfigFactoryStub([]);
    $this->logger = $this->getLoggerFactoryMock();
    $this->languageManager = $this->createMock('\\Drupal\\Core\\Language\\LanguageManagerInterface');
    $this->timeService = $this->createMock('\\Drupal\\Component\\Datetime\\TimeInterface');

    $userHandlerService = new InactiveUsersHandler($this->configFactoryService, $this->logger, $this->languageManager, $this->timeService);
    $container->set('block_inactive_users.deactivate_users', $userHandlerService);
    \Drupal::setContainer($container);

  }

  /**
   * Utility function for getting a LoggerChannelFactory service.
   */
  private function getLoggerFactoryMock() {

    $loggerChannel = $this->getMockBuilder('Drupal\Core\Logger\LoggerChannel')
      ->disableOriginalConstructor()
      ->getMock();
    $loggerChannel->expects($this->any())
      ->method('error')
      ->will($this->returnValue(''));

    $loggerChannelFactory = $this->getMockBuilder('Drupal\Core\Logger\LoggerChannelFactory')
      ->disableOriginalConstructor()
      ->getMock();
    $loggerChannelFactory->expects($this->any())
      ->method('get')
      ->will($this->returnValue($loggerChannel));
    return $loggerChannelFactory;
  }

  /**
   * @covers  \Drupal\block_inactive_users\InactiveUsersHandler::disableInactiveUsersStatus
   *
   * Finds user idle users and disabled them
   */
  public function testDisableInactiveUsersStatus() {

    $user = $this->getMockBuilder('Drupal\user\Entity\User')
      ->disableOriginalConstructor()
      ->getMock();

    $user->expects($this->any())
      ->method('isActive')
      ->will($this->returnValue(FALSE));

    $usersHandler = \Drupal::service('block_inactive_users.deactivate_users');
    $v = $usersHandler->disableInactiveUsersStatus($user, FALSE);
    $this->assertNotEmpty($v);
    $this->assertNotTrue($v->isActive());
  }

}
